@@ -56,7 +56,6 @@ from google.cloud.exceptions import NotFound
 from googleapiclient.discovery import build
 from pandas_gbq import read_gbq
 from pandas_gbq.gbq import GbqConnector  # noqa: F401 used in ``airflow.contrib.hooks.bigquery``
-from requests import Session
 from sqlalchemy import create_engine
 
 from airflow.exceptions import AirflowException, AirflowProviderDeprecationWarning
@@ -80,6 +79,7 @@ if TYPE_CHECKING:
     import pandas as pd
     from google.api_core.page_iterator import HTTPIterator
     from google.api_core.retry import Retry
+    from requests import Session
 
 log = logging.getLogger(__name__)
 
@@ -2116,7 +2116,7 @@ class BigQueryAsyncHook(GoogleBaseAsyncHook):
             job_id=job_id,
             project=project_id,
             token=token,
-            session=cast(Session, session),
+            session=cast("Session", session),
         )
 
     async def _get_job(
@@ -2181,7 +2181,7 @@ class BigQueryAsyncHook(GoogleBaseAsyncHook):
         async with ClientSession() as session:
             self.log.info("Executing get_job_output..")
             job_client = await self.get_job_instance(project_id, job_id, session)
-            job_query_response = await job_client.get_query_results(cast(Session, session))
+            job_query_response = await job_client.get_query_results(cast("Session", session))
             return job_query_response
 
     async def create_job_for_partition_get(
@@ -2201,7 +2201,7 @@ class BigQueryAsyncHook(GoogleBaseAsyncHook):
                 + (f" WHERE table_name='{table_id}'" if table_id else ""),
                 "useLegacySql": False,
             }
-            job_query_resp = await job_client.query(query_request, cast(Session, session))
+            job_query_resp = await job_client.query(query_request, cast("Session", session))
             return job_query_resp["jobReference"]["jobId"]
 
     async def cancel_job(self, job_id: str, project_id: str | None, location: str | None) -> None:
@@ -2381,12 +2381,7 @@ class BigQueryAsyncHook(GoogleBaseAsyncHook):
                 test_results[metric] = float(ratios[metric]) < threshold
 
             self.log.info(
-                (
-                    "Current metric for %s: %s\n"
-                    "Past metric for %s: %s\n"
-                    "Ratio for %s: %s\n"
-                    "Threshold: %s\n"
-                ),
+                ("Current metric for %s: %s\nPast metric for %s: %s\nRatio for %s: %s\nThreshold: %s\n"),
                 metric,
                 cur,
                 metric,
@@ -2451,5 +2446,5 @@ class BigQueryTableAsyncHook(GoogleBaseAsyncHook):
             table_name=table_id,
             project=project_id,
             token=token,
-            session=cast(Session, session),
+            session=cast("Session", session),
         )
